# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kaskada/shared/v1alpha/options.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$kaskada/shared/v1alpha/options.proto\x12\x16kaskada.shared.v1alpha\x1a google/protobuf/descriptor.proto:=\n\tsensitive\x12\x1d.google.protobuf.FieldOptions\x18\xd0\x86\x03 \x01(\x08R\tsensitiveB\xf1\x01\n\x1a\x63om.kaskada.shared.v1alphaB\x0cOptionsProtoP\x01ZKgitlab.com/kaskada/kaskada/wren/gen/go/kaskada/shared/v1alpha;sharedv1alpha\xa2\x02\x03KSX\xaa\x02\x16Kaskada.Shared.V1alpha\xca\x02\x16Kaskada\\Shared\\V1alpha\xe2\x02\"Kaskada\\Shared\\V1alpha\\GPBMetadata\xea\x02\x18Kaskada::Shared::V1alphab\x06proto3')


SENSITIVE_FIELD_NUMBER = 50000
sensitive = DESCRIPTOR.extensions_by_name['sensitive']

if _descriptor._USE_C_DESCRIPTORS == False:
  google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(sensitive)

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\032com.kaskada.shared.v1alphaB\014OptionsProtoP\001ZKgitlab.com/kaskada/kaskada/wren/gen/go/kaskada/shared/v1alpha;sharedv1alpha\242\002\003KSX\252\002\026Kaskada.Shared.V1alpha\312\002\026Kaskada\\Shared\\V1alpha\342\002\"Kaskada\\Shared\\V1alpha\\GPBMetadata\352\002\030Kaskada::Shared::V1alpha'
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kaskada/api/v1alpha/credential.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from kaskada.api.v1alpha import shared_pb2 as kaskada_dot_api_dot_v1alpha_dot_shared__pb2
from kaskada.shared.v1alpha import options_pb2 as kaskada_dot_shared_dot_v1alpha_dot_options__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$kaskada/api/v1alpha/credential.proto\x12\x13kaskada.api.v1alpha\x1a\x1cgoogle/api/annotations.proto\x1a kaskada/api/v1alpha/shared.proto\x1a$kaskada/shared/v1alpha/options.proto\"\x16\n\x14GetCredentialRequest\"\xad\x01\n\x15GetCredentialResponse\x12\x1b\n\tclient_id\x18\x01 \x01(\tR\x08\x63lientId\x12)\n\rclient_secret\x18\x02 \x01(\tB\x04\x80\xb5\x18\x01R\x0c\x63lientSecret\x12L\n\x0frequest_details\x18\x03 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetails2\x8e\x01\n\x11\x43redentialService\x12y\n\x03Get\x12).kaskada.api.v1alpha.GetCredentialRequest\x1a*.kaskada.api.v1alpha.GetCredentialResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/v1alpha/credentialB\xdf\x01\n\x17\x63om.kaskada.api.v1alphaB\x0f\x43redentialProtoP\x01ZEgitlab.com/kaskada/kaskada/wren/gen/go/kaskada/api/v1alpha;apiv1alpha\xa2\x02\x03KAX\xaa\x02\x13Kaskada.Api.V1alpha\xca\x02\x13Kaskada\\Api\\V1alpha\xe2\x02\x1fKaskada\\Api\\V1alpha\\GPBMetadata\xea\x02\x15Kaskada::Api::V1alphab\x06proto3')



_GETCREDENTIALREQUEST = DESCRIPTOR.message_types_by_name['GetCredentialRequest']
_GETCREDENTIALRESPONSE = DESCRIPTOR.message_types_by_name['GetCredentialResponse']
GetCredentialRequest = _reflection.GeneratedProtocolMessageType('GetCredentialRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCREDENTIALREQUEST,
  '__module__' : 'kaskada.api.v1alpha.credential_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.GetCredentialRequest)
  })
_sym_db.RegisterMessage(GetCredentialRequest)

GetCredentialResponse = _reflection.GeneratedProtocolMessageType('GetCredentialResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCREDENTIALRESPONSE,
  '__module__' : 'kaskada.api.v1alpha.credential_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.GetCredentialResponse)
  })
_sym_db.RegisterMessage(GetCredentialResponse)

_CREDENTIALSERVICE = DESCRIPTOR.services_by_name['CredentialService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.kaskada.api.v1alphaB\017CredentialProtoP\001ZEgitlab.com/kaskada/kaskada/wren/gen/go/kaskada/api/v1alpha;apiv1alpha\242\002\003KAX\252\002\023Kaskada.Api.V1alpha\312\002\023Kaskada\\Api\\V1alpha\342\002\037Kaskada\\Api\\V1alpha\\GPBMetadata\352\002\025Kaskada::Api::V1alpha'
  _GETCREDENTIALRESPONSE.fields_by_name['client_secret']._options = None
  _GETCREDENTIALRESPONSE.fields_by_name['client_secret']._serialized_options = b'\200\265\030\001'
  _CREDENTIALSERVICE.methods_by_name['Get']._options = None
  _CREDENTIALSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002\025\022\023/v1alpha/credential'
  _GETCREDENTIALREQUEST._serialized_start=163
  _GETCREDENTIALREQUEST._serialized_end=185
  _GETCREDENTIALRESPONSE._serialized_start=188
  _GETCREDENTIALRESPONSE._serialized_end=361
  _CREDENTIALSERVICE._serialized_start=364
  _CREDENTIALSERVICE._serialized_end=506
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from kaskada.api.v1alpha import compute_pb2 as kaskada_dot_api_dot_v1alpha_dot_compute__pb2


class ComputeServiceStub(object):
    """Service for querying tables and views
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Analyze = channel.unary_unary(
                '/kaskada.api.v1alpha.ComputeService/Analyze',
                request_serializer=kaskada_dot_api_dot_v1alpha_dot_compute__pb2.AnalyzeRequest.SerializeToString,
                response_deserializer=kaskada_dot_api_dot_v1alpha_dot_compute__pb2.AnalyzeResponse.FromString,
                )
        self.Query = channel.unary_unary(
                '/kaskada.api.v1alpha.ComputeService/Query',
                request_serializer=kaskada_dot_api_dot_v1alpha_dot_compute__pb2.QueryRequest.SerializeToString,
                response_deserializer=kaskada_dot_api_dot_v1alpha_dot_compute__pb2.QueryResponse.FromString,
                )
        self.StreamQuery = channel.unary_stream(
                '/kaskada.api.v1alpha.ComputeService/StreamQuery',
                request_serializer=kaskada_dot_api_dot_v1alpha_dot_compute__pb2.StreamQueryRequest.SerializeToString,
                response_deserializer=kaskada_dot_api_dot_v1alpha_dot_compute__pb2.StreamQueryResponse.FromString,
                )


class ComputeServiceServicer(object):
    """Service for querying tables and views
    """

    def Analyze(self, request, context):
        """Analyzes if a Fenl statement can be executed.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Query(self, request, context):
        """Computes the results of a Fenl statement
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamQuery(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ComputeServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Analyze': grpc.unary_unary_rpc_method_handler(
                    servicer.Analyze,
                    request_deserializer=kaskada_dot_api_dot_v1alpha_dot_compute__pb2.AnalyzeRequest.FromString,
                    response_serializer=kaskada_dot_api_dot_v1alpha_dot_compute__pb2.AnalyzeResponse.SerializeToString,
            ),
            'Query': grpc.unary_unary_rpc_method_handler(
                    servicer.Query,
                    request_deserializer=kaskada_dot_api_dot_v1alpha_dot_compute__pb2.QueryRequest.FromString,
                    response_serializer=kaskada_dot_api_dot_v1alpha_dot_compute__pb2.QueryResponse.SerializeToString,
            ),
            'StreamQuery': grpc.unary_stream_rpc_method_handler(
                    servicer.StreamQuery,
                    request_deserializer=kaskada_dot_api_dot_v1alpha_dot_compute__pb2.StreamQueryRequest.FromString,
                    response_serializer=kaskada_dot_api_dot_v1alpha_dot_compute__pb2.StreamQueryResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'kaskada.api.v1alpha.ComputeService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ComputeService(object):
    """Service for querying tables and views
    """

    @staticmethod
    def Analyze(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/kaskada.api.v1alpha.ComputeService/Analyze',
            kaskada_dot_api_dot_v1alpha_dot_compute__pb2.AnalyzeRequest.SerializeToString,
            kaskada_dot_api_dot_v1alpha_dot_compute__pb2.AnalyzeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Query(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/kaskada.api.v1alpha.ComputeService/Query',
            kaskada_dot_api_dot_v1alpha_dot_compute__pb2.QueryRequest.SerializeToString,
            kaskada_dot_api_dot_v1alpha_dot_compute__pb2.QueryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StreamQuery(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/kaskada.api.v1alpha.ComputeService/StreamQuery',
            kaskada_dot_api_dot_v1alpha_dot_compute__pb2.StreamQueryRequest.SerializeToString,
            kaskada_dot_api_dot_v1alpha_dot_compute__pb2.StreamQueryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kaskada/api/v1alpha/test_cases.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from kaskada.shared.v1alpha import options_pb2 as kaskada_dot_shared_dot_v1alpha_dot_options__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$kaskada/api/v1alpha/test_cases.proto\x12\x13kaskada.api.v1alpha\x1a$kaskada/shared/v1alpha/options.proto\"\xf8\x08\n\x0eRedactTestCase\x12&\n\x0froot_safe_value\x18\x01 \x01(\tR\rrootSafeValue\x12\x36\n\x14root_sensitive_value\x18\x02 \x01(\tB\x04\x80\xb5\x18\x01R\x12rootSensitiveValue\x12@\n\x19repeated_sensitive_values\x18\x03 \x03(\tB\x04\x80\xb5\x18\x01R\x17repeatedSensitiveValues\x12\x64\n\x14root_embedded_object\x18\x04 \x01(\x0b\x32\x32.kaskada.api.v1alpha.RedactTestCase.EmbeddedObjectR\x12rootEmbeddedObject\x12l\n\x18repeated_embedded_object\x18\x05 \x03(\x0b\x32\x32.kaskada.api.v1alpha.RedactTestCase.EmbeddedObjectR\x16repeatedEmbeddedObject\x12+\n\x11one_of_safe_value\x18\x07 \x01(\tH\x00R\x0eoneOfSafeValue\x12;\n\x16one_of_sensitive_value\x18\x08 \x01(\tB\x04\x80\xb5\x18\x01H\x00R\x13oneOfSensitiveValue\x12g\n\x15one_of_embedded_value\x18\t \x01(\x0b\x32\x32.kaskada.api.v1alpha.RedactTestCase.EmbeddedObjectH\x00R\x12oneOfEmbeddedValue\x12s\n\x14map_sensitive_values\x18\n \x03(\x0b\x32;.kaskada.api.v1alpha.RedactTestCase.MapSensitiveValuesEntryB\x04\x80\xb5\x18\x01R\x12mapSensitiveValues\x12m\n\x14map_embedded_objects\x18\x0b \x03(\x0b\x32;.kaskada.api.v1alpha.RedactTestCase.MapEmbeddedObjectsEntryR\x12mapEmbeddedObjects\x1a\x45\n\x17MapSensitiveValuesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1ay\n\x17MapEmbeddedObjectsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12H\n\x05value\x18\x02 \x01(\x0b\x32\x32.kaskada.api.v1alpha.RedactTestCase.EmbeddedObjectR\x05value:\x02\x38\x01\x1a\x62\n\x0e\x45mbeddedObject\x12\x1f\n\x0bsafe_string\x18\x01 \x01(\tR\nsafeString\x12/\n\x10sensitive_string\x18\x02 \x01(\tB\x04\x80\xb5\x18\x01R\x0fsensitiveStringB\r\n\x0bone_of_testJ\x04\x08\x06\x10\x07\x42\xde\x01\n\x17\x63om.kaskada.api.v1alphaB\x0eTestCasesProtoP\x01ZEgitlab.com/kaskada/kaskada/wren/gen/go/kaskada/api/v1alpha;apiv1alpha\xa2\x02\x03KAX\xaa\x02\x13Kaskada.Api.V1alpha\xca\x02\x13Kaskada\\Api\\V1alpha\xe2\x02\x1fKaskada\\Api\\V1alpha\\GPBMetadata\xea\x02\x15Kaskada::Api::V1alphab\x06proto3')



_REDACTTESTCASE = DESCRIPTOR.message_types_by_name['RedactTestCase']
_REDACTTESTCASE_MAPSENSITIVEVALUESENTRY = _REDACTTESTCASE.nested_types_by_name['MapSensitiveValuesEntry']
_REDACTTESTCASE_MAPEMBEDDEDOBJECTSENTRY = _REDACTTESTCASE.nested_types_by_name['MapEmbeddedObjectsEntry']
_REDACTTESTCASE_EMBEDDEDOBJECT = _REDACTTESTCASE.nested_types_by_name['EmbeddedObject']
RedactTestCase = _reflection.GeneratedProtocolMessageType('RedactTestCase', (_message.Message,), {

  'MapSensitiveValuesEntry' : _reflection.GeneratedProtocolMessageType('MapSensitiveValuesEntry', (_message.Message,), {
    'DESCRIPTOR' : _REDACTTESTCASE_MAPSENSITIVEVALUESENTRY,
    '__module__' : 'kaskada.api.v1alpha.test_cases_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.RedactTestCase.MapSensitiveValuesEntry)
    })
  ,

  'MapEmbeddedObjectsEntry' : _reflection.GeneratedProtocolMessageType('MapEmbeddedObjectsEntry', (_message.Message,), {
    'DESCRIPTOR' : _REDACTTESTCASE_MAPEMBEDDEDOBJECTSENTRY,
    '__module__' : 'kaskada.api.v1alpha.test_cases_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.RedactTestCase.MapEmbeddedObjectsEntry)
    })
  ,

  'EmbeddedObject' : _reflection.GeneratedProtocolMessageType('EmbeddedObject', (_message.Message,), {
    'DESCRIPTOR' : _REDACTTESTCASE_EMBEDDEDOBJECT,
    '__module__' : 'kaskada.api.v1alpha.test_cases_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.RedactTestCase.EmbeddedObject)
    })
  ,
  'DESCRIPTOR' : _REDACTTESTCASE,
  '__module__' : 'kaskada.api.v1alpha.test_cases_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.RedactTestCase)
  })
_sym_db.RegisterMessage(RedactTestCase)
_sym_db.RegisterMessage(RedactTestCase.MapSensitiveValuesEntry)
_sym_db.RegisterMessage(RedactTestCase.MapEmbeddedObjectsEntry)
_sym_db.RegisterMessage(RedactTestCase.EmbeddedObject)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.kaskada.api.v1alphaB\016TestCasesProtoP\001ZEgitlab.com/kaskada/kaskada/wren/gen/go/kaskada/api/v1alpha;apiv1alpha\242\002\003KAX\252\002\023Kaskada.Api.V1alpha\312\002\023Kaskada\\Api\\V1alpha\342\002\037Kaskada\\Api\\V1alpha\\GPBMetadata\352\002\025Kaskada::Api::V1alpha'
  _REDACTTESTCASE_MAPSENSITIVEVALUESENTRY._options = None
  _REDACTTESTCASE_MAPSENSITIVEVALUESENTRY._serialized_options = b'8\001'
  _REDACTTESTCASE_MAPEMBEDDEDOBJECTSENTRY._options = None
  _REDACTTESTCASE_MAPEMBEDDEDOBJECTSENTRY._serialized_options = b'8\001'
  _REDACTTESTCASE_EMBEDDEDOBJECT.fields_by_name['sensitive_string']._options = None
  _REDACTTESTCASE_EMBEDDEDOBJECT.fields_by_name['sensitive_string']._serialized_options = b'\200\265\030\001'
  _REDACTTESTCASE.fields_by_name['root_sensitive_value']._options = None
  _REDACTTESTCASE.fields_by_name['root_sensitive_value']._serialized_options = b'\200\265\030\001'
  _REDACTTESTCASE.fields_by_name['repeated_sensitive_values']._options = None
  _REDACTTESTCASE.fields_by_name['repeated_sensitive_values']._serialized_options = b'\200\265\030\001'
  _REDACTTESTCASE.fields_by_name['one_of_sensitive_value']._options = None
  _REDACTTESTCASE.fields_by_name['one_of_sensitive_value']._serialized_options = b'\200\265\030\001'
  _REDACTTESTCASE.fields_by_name['map_sensitive_values']._options = None
  _REDACTTESTCASE.fields_by_name['map_sensitive_values']._serialized_options = b'\200\265\030\001'
  _REDACTTESTCASE._serialized_start=100
  _REDACTTESTCASE._serialized_end=1244
  _REDACTTESTCASE_MAPSENSITIVEVALUESENTRY._serialized_start=931
  _REDACTTESTCASE_MAPSENSITIVEVALUESENTRY._serialized_end=1000
  _REDACTTESTCASE_MAPEMBEDDEDOBJECTSENTRY._serialized_start=1002
  _REDACTTESTCASE_MAPEMBEDDEDOBJECTSENTRY._serialized_end=1123
  _REDACTTESTCASE_EMBEDDEDOBJECT._serialized_start=1125
  _REDACTTESTCASE_EMBEDDEDOBJECT._serialized_end=1223
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from kaskada.api.v1alpha import staged_file_pb2 as kaskada_dot_api_dot_v1alpha_dot_staged__file__pb2


class StagedFileServiceStub(object):
    """A service for managing StagedFiles.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListStagedFiles = channel.unary_unary(
                '/kaskada.api.v1alpha.StagedFileService/ListStagedFiles',
                request_serializer=kaskada_dot_api_dot_v1alpha_dot_staged__file__pb2.ListStagedFilesRequest.SerializeToString,
                response_deserializer=kaskada_dot_api_dot_v1alpha_dot_staged__file__pb2.ListStagedFilesResponse.FromString,
                )
        self.GetStagedFile = channel.unary_unary(
                '/kaskada.api.v1alpha.StagedFileService/GetStagedFile',
                request_serializer=kaskada_dot_api_dot_v1alpha_dot_staged__file__pb2.GetStagedFileRequest.SerializeToString,
                response_deserializer=kaskada_dot_api_dot_v1alpha_dot_staged__file__pb2.GetStagedFileResponse.FromString,
                )
        self.CreateStagedFile = channel.unary_unary(
                '/kaskada.api.v1alpha.StagedFileService/CreateStagedFile',
                request_serializer=kaskada_dot_api_dot_v1alpha_dot_staged__file__pb2.CreateStagedFileRequest.SerializeToString,
                response_deserializer=kaskada_dot_api_dot_v1alpha_dot_staged__file__pb2.CreateStagedFileResponse.FromString,
                )


class StagedFileServiceServicer(object):
    """A service for managing StagedFiles.
    """

    def ListStagedFiles(self, request, context):
        """Lists staged files.

        The response includes all StagedFiles defined for the Kaskada
        account. If a search string is provided, only StagedFiles matching
        the search string are returned.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetStagedFile(self, request, context):
        """Gets a staged file.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateStagedFile(self, request, context):
        """Creates a staged file and returns a signed URL for uploading.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_StagedFileServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListStagedFiles': grpc.unary_unary_rpc_method_handler(
                    servicer.ListStagedFiles,
                    request_deserializer=kaskada_dot_api_dot_v1alpha_dot_staged__file__pb2.ListStagedFilesRequest.FromString,
                    response_serializer=kaskada_dot_api_dot_v1alpha_dot_staged__file__pb2.ListStagedFilesResponse.SerializeToString,
            ),
            'GetStagedFile': grpc.unary_unary_rpc_method_handler(
                    servicer.GetStagedFile,
                    request_deserializer=kaskada_dot_api_dot_v1alpha_dot_staged__file__pb2.GetStagedFileRequest.FromString,
                    response_serializer=kaskada_dot_api_dot_v1alpha_dot_staged__file__pb2.GetStagedFileResponse.SerializeToString,
            ),
            'CreateStagedFile': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateStagedFile,
                    request_deserializer=kaskada_dot_api_dot_v1alpha_dot_staged__file__pb2.CreateStagedFileRequest.FromString,
                    response_serializer=kaskada_dot_api_dot_v1alpha_dot_staged__file__pb2.CreateStagedFileResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'kaskada.api.v1alpha.StagedFileService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class StagedFileService(object):
    """A service for managing StagedFiles.
    """

    @staticmethod
    def ListStagedFiles(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/kaskada.api.v1alpha.StagedFileService/ListStagedFiles',
            kaskada_dot_api_dot_v1alpha_dot_staged__file__pb2.ListStagedFilesRequest.SerializeToString,
            kaskada_dot_api_dot_v1alpha_dot_staged__file__pb2.ListStagedFilesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetStagedFile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/kaskada.api.v1alpha.StagedFileService/GetStagedFile',
            kaskada_dot_api_dot_v1alpha_dot_staged__file__pb2.GetStagedFileRequest.SerializeToString,
            kaskada_dot_api_dot_v1alpha_dot_staged__file__pb2.GetStagedFileResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateStagedFile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/kaskada.api.v1alpha.StagedFileService/CreateStagedFile',
            kaskada_dot_api_dot_v1alpha_dot_staged__file__pb2.CreateStagedFileRequest.SerializeToString,
            kaskada_dot_api_dot_v1alpha_dot_staged__file__pb2.CreateStagedFileResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kaskada/puffin/v1alpha/iceberg_table.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from kaskada.shared.v1alpha import catalog_pb2 as kaskada_dot_shared_dot_v1alpha_dot_catalog__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*kaskada/puffin/v1alpha/iceberg_table.proto\x12\x16kaskada.puffin.v1alpha\x1a\x1egoogle/protobuf/wrappers.proto\x1a$kaskada/shared/v1alpha/catalog.proto\"~\n\x0cIcebergTable\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x1c\n\tnamespace\x18\x02 \x01(\tR\tnamespace\x12<\n\x0bsnapshot_id\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\nsnapshotId\"{\n\x11IcebergTableFiles\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12<\n\x0bsnapshot_id\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\nsnapshotId\x12\x14\n\x05paths\x18\x03 \x03(\tR\x05paths\"\x91\x01\n\x0fGetTableRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x1c\n\tnamespace\x18\x02 \x01(\tR\tnamespace\x12L\n\x0e\x63\x61talog_config\x18\x03 \x01(\x0b\x32%.kaskada.shared.v1alpha.CatalogConfigR\rcatalogConfig\"N\n\x10GetTableResponse\x12:\n\x05table\x18\x01 \x01(\x0b\x32$.kaskada.puffin.v1alpha.IcebergTableR\x05table\"\xd4\x01\n\x14GetTableFilesRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x1c\n\tnamespace\x18\x02 \x01(\tR\tnamespace\x12<\n\x0bsnapshot_id\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\nsnapshotId\x12L\n\x0e\x63\x61talog_config\x18\x04 \x01(\x0b\x32%.kaskada.shared.v1alpha.CatalogConfigR\rcatalogConfig\"X\n\x15GetTableFilesResponse\x12?\n\x05table\x18\x01 \x01(\x0b\x32).kaskada.puffin.v1alpha.IcebergTableFilesR\x05table\"\x7f\n\x11ListTablesRequest\x12L\n\x0e\x63\x61talog_config\x18\x01 \x01(\x0b\x32%.kaskada.shared.v1alpha.CatalogConfigR\rcatalogConfig\x12\x1c\n\tnamespace\x18\x02 \x01(\tR\tnamespace\"R\n\x12ListTablesResponse\x12<\n\x06tables\x18\x01 \x03(\x0b\x32$.kaskada.puffin.v1alpha.IcebergTableR\x06tables2\xc6\x02\n\x0cTableService\x12\x65\n\nListTables\x12).kaskada.puffin.v1alpha.ListTablesRequest\x1a*.kaskada.puffin.v1alpha.ListTablesResponse\"\x00\x12_\n\x08GetTable\x12\'.kaskada.puffin.v1alpha.GetTableRequest\x1a(.kaskada.puffin.v1alpha.GetTableResponse\"\x00\x12n\n\rGetTableFiles\x12,.kaskada.puffin.v1alpha.GetTableFilesRequest\x1a-.kaskada.puffin.v1alpha.GetTableFilesResponse\"\x00\x42\xf6\x01\n\x1a\x63om.kaskada.puffin.v1alphaB\x11IcebergTableProtoP\x01ZKgitlab.com/kaskada/kaskada/wren/gen/go/kaskada/puffin/v1alpha;puffinv1alpha\xa2\x02\x03KPX\xaa\x02\x16Kaskada.Puffin.V1alpha\xca\x02\x16Kaskada\\Puffin\\V1alpha\xe2\x02\"Kaskada\\Puffin\\V1alpha\\GPBMetadata\xea\x02\x18Kaskada::Puffin::V1alphab\x06proto3')



_ICEBERGTABLE = DESCRIPTOR.message_types_by_name['IcebergTable']
_ICEBERGTABLEFILES = DESCRIPTOR.message_types_by_name['IcebergTableFiles']
_GETTABLEREQUEST = DESCRIPTOR.message_types_by_name['GetTableRequest']
_GETTABLERESPONSE = DESCRIPTOR.message_types_by_name['GetTableResponse']
_GETTABLEFILESREQUEST = DESCRIPTOR.message_types_by_name['GetTableFilesRequest']
_GETTABLEFILESRESPONSE = DESCRIPTOR.message_types_by_name['GetTableFilesResponse']
_LISTTABLESREQUEST = DESCRIPTOR.message_types_by_name['ListTablesRequest']
_LISTTABLESRESPONSE = DESCRIPTOR.message_types_by_name['ListTablesResponse']
IcebergTable = _reflection.GeneratedProtocolMessageType('IcebergTable', (_message.Message,), {
  'DESCRIPTOR' : _ICEBERGTABLE,
  '__module__' : 'kaskada.puffin.v1alpha.iceberg_table_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.puffin.v1alpha.IcebergTable)
  })
_sym_db.RegisterMessage(IcebergTable)

IcebergTableFiles = _reflection.GeneratedProtocolMessageType('IcebergTableFiles', (_message.Message,), {
  'DESCRIPTOR' : _ICEBERGTABLEFILES,
  '__module__' : 'kaskada.puffin.v1alpha.iceberg_table_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.puffin.v1alpha.IcebergTableFiles)
  })
_sym_db.RegisterMessage(IcebergTableFiles)

GetTableRequest = _reflection.GeneratedProtocolMessageType('GetTableRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTABLEREQUEST,
  '__module__' : 'kaskada.puffin.v1alpha.iceberg_table_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.puffin.v1alpha.GetTableRequest)
  })
_sym_db.RegisterMessage(GetTableRequest)

GetTableResponse = _reflection.GeneratedProtocolMessageType('GetTableResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETTABLERESPONSE,
  '__module__' : 'kaskada.puffin.v1alpha.iceberg_table_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.puffin.v1alpha.GetTableResponse)
  })
_sym_db.RegisterMessage(GetTableResponse)

GetTableFilesRequest = _reflection.GeneratedProtocolMessageType('GetTableFilesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTABLEFILESREQUEST,
  '__module__' : 'kaskada.puffin.v1alpha.iceberg_table_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.puffin.v1alpha.GetTableFilesRequest)
  })
_sym_db.RegisterMessage(GetTableFilesRequest)

GetTableFilesResponse = _reflection.GeneratedProtocolMessageType('GetTableFilesResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETTABLEFILESRESPONSE,
  '__module__' : 'kaskada.puffin.v1alpha.iceberg_table_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.puffin.v1alpha.GetTableFilesResponse)
  })
_sym_db.RegisterMessage(GetTableFilesResponse)

ListTablesRequest = _reflection.GeneratedProtocolMessageType('ListTablesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTTABLESREQUEST,
  '__module__' : 'kaskada.puffin.v1alpha.iceberg_table_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.puffin.v1alpha.ListTablesRequest)
  })
_sym_db.RegisterMessage(ListTablesRequest)

ListTablesResponse = _reflection.GeneratedProtocolMessageType('ListTablesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTTABLESRESPONSE,
  '__module__' : 'kaskada.puffin.v1alpha.iceberg_table_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.puffin.v1alpha.ListTablesResponse)
  })
_sym_db.RegisterMessage(ListTablesResponse)

_TABLESERVICE = DESCRIPTOR.services_by_name['TableService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\032com.kaskada.puffin.v1alphaB\021IcebergTableProtoP\001ZKgitlab.com/kaskada/kaskada/wren/gen/go/kaskada/puffin/v1alpha;puffinv1alpha\242\002\003KPX\252\002\026Kaskada.Puffin.V1alpha\312\002\026Kaskada\\Puffin\\V1alpha\342\002\"Kaskada\\Puffin\\V1alpha\\GPBMetadata\352\002\030Kaskada::Puffin::V1alpha'
  _ICEBERGTABLE._serialized_start=140
  _ICEBERGTABLE._serialized_end=266
  _ICEBERGTABLEFILES._serialized_start=268
  _ICEBERGTABLEFILES._serialized_end=391
  _GETTABLEREQUEST._serialized_start=394
  _GETTABLEREQUEST._serialized_end=539
  _GETTABLERESPONSE._serialized_start=541
  _GETTABLERESPONSE._serialized_end=619
  _GETTABLEFILESREQUEST._serialized_start=622
  _GETTABLEFILESREQUEST._serialized_end=834
  _GETTABLEFILESRESPONSE._serialized_start=836
  _GETTABLEFILESRESPONSE._serialized_end=924
  _LISTTABLESREQUEST._serialized_start=926
  _LISTTABLESREQUEST._serialized_end=1053
  _LISTTABLESRESPONSE._serialized_start=1055
  _LISTTABLESRESPONSE._serialized_end=1137
  _TABLESERVICE._serialized_start=1140
  _TABLESERVICE._serialized_end=1466
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kaskada/api/v1alpha/materialization.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from kaskada.api.v1alpha import compute_pb2 as kaskada_dot_api_dot_v1alpha_dot_compute__pb2
from kaskada.api.v1alpha import shared_pb2 as kaskada_dot_api_dot_v1alpha_dot_shared__pb2
from kaskada.fenl.v1alpha import schema_pb2 as kaskada_dot_fenl_dot_v1alpha_dot_schema__pb2
from kaskada.prepare.v1alpha import slice_pb2 as kaskada_dot_prepare_dot_v1alpha_dot_slice__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)kaskada/api/v1alpha/materialization.proto\x12\x13kaskada.api.v1alpha\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a!kaskada/api/v1alpha/compute.proto\x1a kaskada/api/v1alpha/shared.proto\x1a!kaskada/fenl/v1alpha/schema.proto\x1a#kaskada/prepare/v1alpha/slice.proto\x1a\x17validate/validate.proto\"\x8e\x05\n\x0fMaterialization\x12\x32\n\x12materialization_id\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x11materializationId\x12:\n\x14materialization_name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x13materializationName\x12@\n\x0b\x63reate_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\x12\x14\n\x05query\x18\x04 \x01(\tR\x05query\x12<\n\nwith_views\x18\x05 \x03(\x0b\x32\x1d.kaskada.api.v1alpha.WithViewR\twithViews\x12J\n\tredis_a_i\x18\x06 \x01(\x0b\x32,.kaskada.api.v1alpha.Materialization.RedisAIH\x00R\x07redisAI\x12\x39\n\x06schema\x18\x07 \x01(\x0b\x32\x1c.kaskada.fenl.v1alpha.SchemaB\x03\xe0\x41\x03R\x06schema\x12;\n\x05slice\x18\x08 \x01(\x0b\x32%.kaskada.prepare.v1alpha.SliceRequestR\x05slice\x12>\n\x08\x61nalysis\x18\t \x01(\x0b\x32\x1d.kaskada.api.v1alpha.AnalysisB\x03\xe0\x41\x03R\x08\x61nalysis\x1a\x62\n\x07RedisAI\x12\x19\n\x02\x64\x62\x18\x01 \x01(\x05\x42\t\xfa\x42\x06\x1a\x04\x18\x0f(\x00R\x02\x64\x62\x12\x1b\n\x04host\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04host\x12\x1f\n\x04port\x18\x03 \x01(\x05\x42\x0b\xfa\x42\x08\x1a\x06\x18\xff\xff\x03 \x00R\x04portB\r\n\x0b\x64\x65stination\"}\n\x1bListMaterializationsRequest\x12\x16\n\x06search\x18\x01 \x01(\tR\x06search\x12\'\n\tpage_size\x18\x02 \x01(\x05\x42\n\xfa\x42\x07\x1a\x05\x18\xe8\x07(\x00R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"\xe6\x01\n\x1cListMaterializationsResponse\x12P\n\x10materializations\x18\x01 \x03(\x0b\x32$.kaskada.api.v1alpha.MaterializationR\x10materializations\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12L\n\x0frequest_details\x18\x03 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetails\"W\n\x19GetMaterializationRequest\x12:\n\x14materialization_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x13materializationName\"\xba\x01\n\x1aGetMaterializationResponse\x12N\n\x0fmaterialization\x18\x01 \x01(\x0b\x32$.kaskada.api.v1alpha.MaterializationR\x0fmaterialization\x12L\n\x0frequest_details\x18\x02 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetails\"n\n\x1c\x43reateMaterializationRequest\x12N\n\x0fmaterialization\x18\x01 \x01(\x0b\x32$.kaskada.api.v1alpha.MaterializationR\x0fmaterialization\"\xf8\x01\n\x1d\x43reateMaterializationResponse\x12N\n\x0fmaterialization\x18\x01 \x01(\x0b\x32$.kaskada.api.v1alpha.MaterializationR\x0fmaterialization\x12L\n\x0frequest_details\x18\x02 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetails\x12\x39\n\x08\x61nalysis\x18\x03 \x01(\x0b\x32\x1d.kaskada.api.v1alpha.AnalysisR\x08\x61nalysis\"Z\n\x1c\x44\x65leteMaterializationRequest\x12:\n\x14materialization_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x13materializationName\"s\n\x1d\x44\x65leteMaterializationResponse\x12L\n\x0frequest_details\x18\x02 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetailsJ\x04\x08\x01\x10\x02\x32\xdf\x05\n\x16MaterializationService\x12\x9e\x01\n\x14ListMaterializations\x12\x30.kaskada.api.v1alpha.ListMaterializationsRequest\x1a\x31.kaskada.api.v1alpha.ListMaterializationsResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/v1alpha/materializations\x12\xb1\x01\n\x12GetMaterialization\x12..kaskada.api.v1alpha.GetMaterializationRequest\x1a/.kaskada.api.v1alpha.GetMaterializationResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/v1alpha/materializations/{materialization_name=*}\x12\xb2\x01\n\x15\x43reateMaterialization\x12\x31.kaskada.api.v1alpha.CreateMaterializationRequest\x1a\x32.kaskada.api.v1alpha.CreateMaterializationResponse\"2\x82\xd3\xe4\x93\x02,:\x0fmaterialization\"\x19/v1alpha/materializations\x12\xba\x01\n\x15\x44\x65leteMaterialization\x12\x31.kaskada.api.v1alpha.DeleteMaterializationRequest\x1a\x32.kaskada.api.v1alpha.DeleteMaterializationResponse\":\x82\xd3\xe4\x93\x02\x34*2/v1alpha/materializations/{materialization_name=*}B\xe4\x01\n\x17\x63om.kaskada.api.v1alphaB\x14MaterializationProtoP\x01ZEgitlab.com/kaskada/kaskada/wren/gen/go/kaskada/api/v1alpha;apiv1alpha\xa2\x02\x03KAX\xaa\x02\x13Kaskada.Api.V1alpha\xca\x02\x13Kaskada\\Api\\V1alpha\xe2\x02\x1fKaskada\\Api\\V1alpha\\GPBMetadata\xea\x02\x15Kaskada::Api::V1alphab\x06proto3')



_MATERIALIZATION = DESCRIPTOR.message_types_by_name['Materialization']
_MATERIALIZATION_REDISAI = _MATERIALIZATION.nested_types_by_name['RedisAI']
_LISTMATERIALIZATIONSREQUEST = DESCRIPTOR.message_types_by_name['ListMaterializationsRequest']
_LISTMATERIALIZATIONSRESPONSE = DESCRIPTOR.message_types_by_name['ListMaterializationsResponse']
_GETMATERIALIZATIONREQUEST = DESCRIPTOR.message_types_by_name['GetMaterializationRequest']
_GETMATERIALIZATIONRESPONSE = DESCRIPTOR.message_types_by_name['GetMaterializationResponse']
_CREATEMATERIALIZATIONREQUEST = DESCRIPTOR.message_types_by_name['CreateMaterializationRequest']
_CREATEMATERIALIZATIONRESPONSE = DESCRIPTOR.message_types_by_name['CreateMaterializationResponse']
_DELETEMATERIALIZATIONREQUEST = DESCRIPTOR.message_types_by_name['DeleteMaterializationRequest']
_DELETEMATERIALIZATIONRESPONSE = DESCRIPTOR.message_types_by_name['DeleteMaterializationResponse']
Materialization = _reflection.GeneratedProtocolMessageType('Materialization', (_message.Message,), {

  'RedisAI' : _reflection.GeneratedProtocolMessageType('RedisAI', (_message.Message,), {
    'DESCRIPTOR' : _MATERIALIZATION_REDISAI,
    '__module__' : 'kaskada.api.v1alpha.materialization_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.Materialization.RedisAI)
    })
  ,
  'DESCRIPTOR' : _MATERIALIZATION,
  '__module__' : 'kaskada.api.v1alpha.materialization_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.Materialization)
  })
_sym_db.RegisterMessage(Materialization)
_sym_db.RegisterMessage(Materialization.RedisAI)

ListMaterializationsRequest = _reflection.GeneratedProtocolMessageType('ListMaterializationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTMATERIALIZATIONSREQUEST,
  '__module__' : 'kaskada.api.v1alpha.materialization_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.ListMaterializationsRequest)
  })
_sym_db.RegisterMessage(ListMaterializationsRequest)

ListMaterializationsResponse = _reflection.GeneratedProtocolMessageType('ListMaterializationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTMATERIALIZATIONSRESPONSE,
  '__module__' : 'kaskada.api.v1alpha.materialization_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.ListMaterializationsResponse)
  })
_sym_db.RegisterMessage(ListMaterializationsResponse)

GetMaterializationRequest = _reflection.GeneratedProtocolMessageType('GetMaterializationRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMATERIALIZATIONREQUEST,
  '__module__' : 'kaskada.api.v1alpha.materialization_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.GetMaterializationRequest)
  })
_sym_db.RegisterMessage(GetMaterializationRequest)

GetMaterializationResponse = _reflection.GeneratedProtocolMessageType('GetMaterializationResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMATERIALIZATIONRESPONSE,
  '__module__' : 'kaskada.api.v1alpha.materialization_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.GetMaterializationResponse)
  })
_sym_db.RegisterMessage(GetMaterializationResponse)

CreateMaterializationRequest = _reflection.GeneratedProtocolMessageType('CreateMaterializationRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMATERIALIZATIONREQUEST,
  '__module__' : 'kaskada.api.v1alpha.materialization_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.CreateMaterializationRequest)
  })
_sym_db.RegisterMessage(CreateMaterializationRequest)

CreateMaterializationResponse = _reflection.GeneratedProtocolMessageType('CreateMaterializationResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMATERIALIZATIONRESPONSE,
  '__module__' : 'kaskada.api.v1alpha.materialization_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.CreateMaterializationResponse)
  })
_sym_db.RegisterMessage(CreateMaterializationResponse)

DeleteMaterializationRequest = _reflection.GeneratedProtocolMessageType('DeleteMaterializationRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMATERIALIZATIONREQUEST,
  '__module__' : 'kaskada.api.v1alpha.materialization_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.DeleteMaterializationRequest)
  })
_sym_db.RegisterMessage(DeleteMaterializationRequest)

DeleteMaterializationResponse = _reflection.GeneratedProtocolMessageType('DeleteMaterializationResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMATERIALIZATIONRESPONSE,
  '__module__' : 'kaskada.api.v1alpha.materialization_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.DeleteMaterializationResponse)
  })
_sym_db.RegisterMessage(DeleteMaterializationResponse)

_MATERIALIZATIONSERVICE = DESCRIPTOR.services_by_name['MaterializationService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.kaskada.api.v1alphaB\024MaterializationProtoP\001ZEgitlab.com/kaskada/kaskada/wren/gen/go/kaskada/api/v1alpha;apiv1alpha\242\002\003KAX\252\002\023Kaskada.Api.V1alpha\312\002\023Kaskada\\Api\\V1alpha\342\002\037Kaskada\\Api\\V1alpha\\GPBMetadata\352\002\025Kaskada::Api::V1alpha'
  _MATERIALIZATION_REDISAI.fields_by_name['db']._options = None
  _MATERIALIZATION_REDISAI.fields_by_name['db']._serialized_options = b'\372B\006\032\004\030\017(\000'
  _MATERIALIZATION_REDISAI.fields_by_name['host']._options = None
  _MATERIALIZATION_REDISAI.fields_by_name['host']._serialized_options = b'\372B\004r\002\020\001'
  _MATERIALIZATION_REDISAI.fields_by_name['port']._options = None
  _MATERIALIZATION_REDISAI.fields_by_name['port']._serialized_options = b'\372B\010\032\006\030\377\377\003 \000'
  _MATERIALIZATION.fields_by_name['materialization_id']._options = None
  _MATERIALIZATION.fields_by_name['materialization_id']._serialized_options = b'\340A\003'
  _MATERIALIZATION.fields_by_name['materialization_name']._options = None
  _MATERIALIZATION.fields_by_name['materialization_name']._serialized_options = b'\372B\004r\002\020\001'
  _MATERIALIZATION.fields_by_name['create_time']._options = None
  _MATERIALIZATION.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _MATERIALIZATION.fields_by_name['schema']._options = None
  _MATERIALIZATION.fields_by_name['schema']._serialized_options = b'\340A\003'
  _MATERIALIZATION.fields_by_name['analysis']._options = None
  _MATERIALIZATION.fields_by_name['analysis']._serialized_options = b'\340A\003'
  _LISTMATERIALIZATIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTMATERIALIZATIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\372B\007\032\005\030\350\007(\000'
  _GETMATERIALIZATIONREQUEST.fields_by_name['materialization_name']._options = None
  _GETMATERIALIZATIONREQUEST.fields_by_name['materialization_name']._serialized_options = b'\372B\004r\002\020\001'
  _DELETEMATERIALIZATIONREQUEST.fields_by_name['materialization_name']._options = None
  _DELETEMATERIALIZATIONREQUEST.fields_by_name['materialization_name']._serialized_options = b'\372B\004r\002\020\001'
  _MATERIALIZATIONSERVICE.methods_by_name['ListMaterializations']._options = None
  _MATERIALIZATIONSERVICE.methods_by_name['ListMaterializations']._serialized_options = b'\202\323\344\223\002\033\022\031/v1alpha/materializations'
  _MATERIALIZATIONSERVICE.methods_by_name['GetMaterialization']._options = None
  _MATERIALIZATIONSERVICE.methods_by_name['GetMaterialization']._serialized_options = b'\202\323\344\223\0024\0222/v1alpha/materializations/{materialization_name=*}'
  _MATERIALIZATIONSERVICE.methods_by_name['CreateMaterialization']._options = None
  _MATERIALIZATIONSERVICE.methods_by_name['CreateMaterialization']._serialized_options = b'\202\323\344\223\002,:\017materialization\"\031/v1alpha/materializations'
  _MATERIALIZATIONSERVICE.methods_by_name['DeleteMaterialization']._options = None
  _MATERIALIZATIONSERVICE.methods_by_name['DeleteMaterialization']._serialized_options = b'\202\323\344\223\0024*2/v1alpha/materializations/{materialization_name=*}'
  _MATERIALIZATION._serialized_start=329
  _MATERIALIZATION._serialized_end=983
  _MATERIALIZATION_REDISAI._serialized_start=870
  _MATERIALIZATION_REDISAI._serialized_end=968
  _LISTMATERIALIZATIONSREQUEST._serialized_start=985
  _LISTMATERIALIZATIONSREQUEST._serialized_end=1110
  _LISTMATERIALIZATIONSRESPONSE._serialized_start=1113
  _LISTMATERIALIZATIONSRESPONSE._serialized_end=1343
  _GETMATERIALIZATIONREQUEST._serialized_start=1345
  _GETMATERIALIZATIONREQUEST._serialized_end=1432
  _GETMATERIALIZATIONRESPONSE._serialized_start=1435
  _GETMATERIALIZATIONRESPONSE._serialized_end=1621
  _CREATEMATERIALIZATIONREQUEST._serialized_start=1623
  _CREATEMATERIALIZATIONREQUEST._serialized_end=1733
  _CREATEMATERIALIZATIONRESPONSE._serialized_start=1736
  _CREATEMATERIALIZATIONRESPONSE._serialized_end=1984
  _DELETEMATERIALIZATIONREQUEST._serialized_start=1986
  _DELETEMATERIALIZATIONREQUEST._serialized_end=2076
  _DELETEMATERIALIZATIONRESPONSE._serialized_start=2078
  _DELETEMATERIALIZATIONRESPONSE._serialized_end=2193
  _MATERIALIZATIONSERVICE._serialized_start=2196
  _MATERIALIZATIONSERVICE._serialized_end=2931
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kaskada/api/v1alpha/shared.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from kaskada.errdetails.v1alpha import fenl_diagnostics_pb2 as kaskada_dot_errdetails_dot_v1alpha_dot_fenl__diagnostics__pb2
from kaskada.shared.v1alpha import options_pb2 as kaskada_dot_shared_dot_v1alpha_dot_options__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n kaskada/api/v1alpha/shared.proto\x12\x13kaskada.api.v1alpha\x1a\x31kaskada/errdetails/v1alpha/fenl_diagnostics.proto\x1a$kaskada/shared/v1alpha/options.proto\x1a\x17validate/validate.proto\"\xc7\x01\n\x08\x41nalysis\x12#\n\rmissing_names\x18\x01 \x03(\tR\x0cmissingNames\x12V\n\x10\x66\x65nl_diagnostics\x18\x02 \x01(\x0b\x32+.kaskada.errdetails.v1alpha.FenlDiagnosticsR\x0f\x66\x65nlDiagnostics\x12\x1f\n\x0b\x63\x61n_execute\x18\x03 \x01(\x08R\ncanExecute\x12\x1d\n\nfree_names\x18\x04 \x03(\tR\tfreeNames\"\xf2\x01\n\rAWSCredential\x12M\n\naccess_key\x18\x01 \x01(\x0b\x32,.kaskada.api.v1alpha.AWSCredential.AccessKeyH\x00R\taccessKey\x1a\x7f\n\tAccessKey\x12\x32\n\x11\x61ws_access_key_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x0e\x61wsAccessKeyId\x12>\n\x15\x61ws_secret_access_key\x18\x02 \x01(\tB\x0b\xfa\x42\x04r\x02\x10\x01\x80\xb5\x18\x01R\x12\x61wsSecretAccessKeyB\x11\n\ncredential\x12\x03\xf8\x42\x01\"\xfc\x02\n\x0e\x45xternalS3File\x12;\n\x14virtual_hosted_style\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00R\x12virtualHostedStyle\x12\x61\n\x11\x62ucket_region_key\x18\x02 \x01(\x0b\x32\x33.kaskada.api.v1alpha.ExternalS3File.BucketRegionKeyH\x00R\x0f\x62ucketRegionKey\x12I\n\x0e\x61ws_credential\x18\x10 \x01(\x0b\x32\".kaskada.api.v1alpha.AWSCredentialR\rawsCredential\x1an\n\x0f\x42ucketRegionKey\x12\x1f\n\x06\x62ucket\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x06\x62ucket\x12\x1f\n\x06region\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x06region\x12\x19\n\x03key\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x03keyB\x0f\n\x08location\x12\x03\xf8\x42\x01\"/\n\x0eRequestDetails\x12\x1d\n\nrequest_id\x18\x01 \x01(\tR\trequestIdB\xdb\x01\n\x17\x63om.kaskada.api.v1alphaB\x0bSharedProtoP\x01ZEgitlab.com/kaskada/kaskada/wren/gen/go/kaskada/api/v1alpha;apiv1alpha\xa2\x02\x03KAX\xaa\x02\x13Kaskada.Api.V1alpha\xca\x02\x13Kaskada\\Api\\V1alpha\xe2\x02\x1fKaskada\\Api\\V1alpha\\GPBMetadata\xea\x02\x15Kaskada::Api::V1alphab\x06proto3')



_ANALYSIS = DESCRIPTOR.message_types_by_name['Analysis']
_AWSCREDENTIAL = DESCRIPTOR.message_types_by_name['AWSCredential']
_AWSCREDENTIAL_ACCESSKEY = _AWSCREDENTIAL.nested_types_by_name['AccessKey']
_EXTERNALS3FILE = DESCRIPTOR.message_types_by_name['ExternalS3File']
_EXTERNALS3FILE_BUCKETREGIONKEY = _EXTERNALS3FILE.nested_types_by_name['BucketRegionKey']
_REQUESTDETAILS = DESCRIPTOR.message_types_by_name['RequestDetails']
Analysis = _reflection.GeneratedProtocolMessageType('Analysis', (_message.Message,), {
  'DESCRIPTOR' : _ANALYSIS,
  '__module__' : 'kaskada.api.v1alpha.shared_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.Analysis)
  })
_sym_db.RegisterMessage(Analysis)

AWSCredential = _reflection.GeneratedProtocolMessageType('AWSCredential', (_message.Message,), {

  'AccessKey' : _reflection.GeneratedProtocolMessageType('AccessKey', (_message.Message,), {
    'DESCRIPTOR' : _AWSCREDENTIAL_ACCESSKEY,
    '__module__' : 'kaskada.api.v1alpha.shared_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.AWSCredential.AccessKey)
    })
  ,
  'DESCRIPTOR' : _AWSCREDENTIAL,
  '__module__' : 'kaskada.api.v1alpha.shared_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.AWSCredential)
  })
_sym_db.RegisterMessage(AWSCredential)
_sym_db.RegisterMessage(AWSCredential.AccessKey)

ExternalS3File = _reflection.GeneratedProtocolMessageType('ExternalS3File', (_message.Message,), {

  'BucketRegionKey' : _reflection.GeneratedProtocolMessageType('BucketRegionKey', (_message.Message,), {
    'DESCRIPTOR' : _EXTERNALS3FILE_BUCKETREGIONKEY,
    '__module__' : 'kaskada.api.v1alpha.shared_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.ExternalS3File.BucketRegionKey)
    })
  ,
  'DESCRIPTOR' : _EXTERNALS3FILE,
  '__module__' : 'kaskada.api.v1alpha.shared_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.ExternalS3File)
  })
_sym_db.RegisterMessage(ExternalS3File)
_sym_db.RegisterMessage(ExternalS3File.BucketRegionKey)

RequestDetails = _reflection.GeneratedProtocolMessageType('RequestDetails', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTDETAILS,
  '__module__' : 'kaskada.api.v1alpha.shared_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.RequestDetails)
  })
_sym_db.RegisterMessage(RequestDetails)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.kaskada.api.v1alphaB\013SharedProtoP\001ZEgitlab.com/kaskada/kaskada/wren/gen/go/kaskada/api/v1alpha;apiv1alpha\242\002\003KAX\252\002\023Kaskada.Api.V1alpha\312\002\023Kaskada\\Api\\V1alpha\342\002\037Kaskada\\Api\\V1alpha\\GPBMetadata\352\002\025Kaskada::Api::V1alpha'
  _AWSCREDENTIAL_ACCESSKEY.fields_by_name['aws_access_key_id']._options = None
  _AWSCREDENTIAL_ACCESSKEY.fields_by_name['aws_access_key_id']._serialized_options = b'\372B\004r\002\020\001'
  _AWSCREDENTIAL_ACCESSKEY.fields_by_name['aws_secret_access_key']._options = None
  _AWSCREDENTIAL_ACCESSKEY.fields_by_name['aws_secret_access_key']._serialized_options = b'\372B\004r\002\020\001\200\265\030\001'
  _AWSCREDENTIAL.oneofs_by_name['credential']._options = None
  _AWSCREDENTIAL.oneofs_by_name['credential']._serialized_options = b'\370B\001'
  _EXTERNALS3FILE_BUCKETREGIONKEY.fields_by_name['bucket']._options = None
  _EXTERNALS3FILE_BUCKETREGIONKEY.fields_by_name['bucket']._serialized_options = b'\372B\004r\002\020\001'
  _EXTERNALS3FILE_BUCKETREGIONKEY.fields_by_name['region']._options = None
  _EXTERNALS3FILE_BUCKETREGIONKEY.fields_by_name['region']._serialized_options = b'\372B\004r\002\020\001'
  _EXTERNALS3FILE_BUCKETREGIONKEY.fields_by_name['key']._options = None
  _EXTERNALS3FILE_BUCKETREGIONKEY.fields_by_name['key']._serialized_options = b'\372B\004r\002\020\001'
  _EXTERNALS3FILE.oneofs_by_name['location']._options = None
  _EXTERNALS3FILE.oneofs_by_name['location']._serialized_options = b'\370B\001'
  _EXTERNALS3FILE.fields_by_name['virtual_hosted_style']._options = None
  _EXTERNALS3FILE.fields_by_name['virtual_hosted_style']._serialized_options = b'\372B\004r\002\020\001'
  _ANALYSIS._serialized_start=172
  _ANALYSIS._serialized_end=371
  _AWSCREDENTIAL._serialized_start=374
  _AWSCREDENTIAL._serialized_end=616
  _AWSCREDENTIAL_ACCESSKEY._serialized_start=470
  _AWSCREDENTIAL_ACCESSKEY._serialized_end=597
  _EXTERNALS3FILE._serialized_start=619
  _EXTERNALS3FILE._serialized_end=999
  _EXTERNALS3FILE_BUCKETREGIONKEY._serialized_start=872
  _EXTERNALS3FILE_BUCKETREGIONKEY._serialized_end=982
  _REQUESTDETAILS._serialized_start=1001
  _REQUESTDETAILS._serialized_end=1048
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kaskada/errdetails/v1alpha/fenl_diagnostics.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1kaskada/errdetails/v1alpha/fenl_diagnostics.proto\x12\x1akaskada.errdetails.v1alpha\"\x87\x01\n\x0f\x46\x65nlDiagnostics\x12U\n\x10\x66\x65nl_diagnostics\x18\x01 \x03(\x0b\x32*.kaskada.errdetails.v1alpha.FenlDiagnosticR\x0f\x66\x65nlDiagnostics\x12\x1d\n\nnum_errors\x18\x02 \x01(\x03R\tnumErrors\"\xc7\x01\n\x0e\x46\x65nlDiagnostic\x12@\n\x08severity\x18\x01 \x01(\x0e\x32$.kaskada.errdetails.v1alpha.SeverityR\x08severity\x12\x12\n\x04\x63ode\x18\x02 \x01(\tR\x04\x63ode\x12\x18\n\x07message\x18\x03 \x01(\tR\x07message\x12\'\n\x0fsource_location\x18\x04 \x01(\tR\x0esourceLocation\x12\x1c\n\tformatted\x18\x05 \x01(\tR\tformatted*\x86\x01\n\x08Severity\x12\x18\n\x14SEVERITY_UNSPECIFIED\x10\x00\x12\x10\n\x0cSEVERITY_BUG\x10\x01\x12\x12\n\x0eSEVERITY_ERROR\x10\x02\x12\x14\n\x10SEVERITY_WARNING\x10\x03\x12\x11\n\rSEVERITY_NOTE\x10\x04\x12\x11\n\rSEVERITY_HELP\x10\x05\x42\x95\x02\n\x1e\x63om.kaskada.errdetails.v1alphaB\x14\x46\x65nlDiagnosticsProtoP\x01ZSgitlab.com/kaskada/kaskada/wren/gen/go/kaskada/errdetails/v1alpha;errdetailsv1alpha\xa2\x02\x03KEX\xaa\x02\x1aKaskada.Errdetails.V1alpha\xca\x02\x1aKaskada\\Errdetails\\V1alpha\xe2\x02&Kaskada\\Errdetails\\V1alpha\\GPBMetadata\xea\x02\x1cKaskada::Errdetails::V1alphab\x06proto3')

_SEVERITY = DESCRIPTOR.enum_types_by_name['Severity']
Severity = enum_type_wrapper.EnumTypeWrapper(_SEVERITY)
SEVERITY_UNSPECIFIED = 0
SEVERITY_BUG = 1
SEVERITY_ERROR = 2
SEVERITY_WARNING = 3
SEVERITY_NOTE = 4
SEVERITY_HELP = 5


_FENLDIAGNOSTICS = DESCRIPTOR.message_types_by_name['FenlDiagnostics']
_FENLDIAGNOSTIC = DESCRIPTOR.message_types_by_name['FenlDiagnostic']
FenlDiagnostics = _reflection.GeneratedProtocolMessageType('FenlDiagnostics', (_message.Message,), {
  'DESCRIPTOR' : _FENLDIAGNOSTICS,
  '__module__' : 'kaskada.errdetails.v1alpha.fenl_diagnostics_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.errdetails.v1alpha.FenlDiagnostics)
  })
_sym_db.RegisterMessage(FenlDiagnostics)

FenlDiagnostic = _reflection.GeneratedProtocolMessageType('FenlDiagnostic', (_message.Message,), {
  'DESCRIPTOR' : _FENLDIAGNOSTIC,
  '__module__' : 'kaskada.errdetails.v1alpha.fenl_diagnostics_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.errdetails.v1alpha.FenlDiagnostic)
  })
_sym_db.RegisterMessage(FenlDiagnostic)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036com.kaskada.errdetails.v1alphaB\024FenlDiagnosticsProtoP\001ZSgitlab.com/kaskada/kaskada/wren/gen/go/kaskada/errdetails/v1alpha;errdetailsv1alpha\242\002\003KEX\252\002\032Kaskada.Errdetails.V1alpha\312\002\032Kaskada\\Errdetails\\V1alpha\342\002&Kaskada\\Errdetails\\V1alpha\\GPBMetadata\352\002\034Kaskada::Errdetails::V1alpha'
  _SEVERITY._serialized_start=422
  _SEVERITY._serialized_end=556
  _FENLDIAGNOSTICS._serialized_start=82
  _FENLDIAGNOSTICS._serialized_end=217
  _FENLDIAGNOSTIC._serialized_start=220
  _FENLDIAGNOSTIC._serialized_end=419
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kaskada/api/v1alpha/spec.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from kaskada.api.v1alpha import materialization_pb2 as kaskada_dot_api_dot_v1alpha_dot_materialization__pb2
from kaskada.api.v1alpha import table_pb2 as kaskada_dot_api_dot_v1alpha_dot_table__pb2
from kaskada.api.v1alpha import view_pb2 as kaskada_dot_api_dot_v1alpha_dot_view__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ekaskada/api/v1alpha/spec.proto\x12\x13kaskada.api.v1alpha\x1a)kaskada/api/v1alpha/materialization.proto\x1a\x1fkaskada/api/v1alpha/table.proto\x1a\x1ekaskada/api/v1alpha/view.proto\"\xbd\x01\n\x04Spec\x12\x32\n\x06tables\x18\x01 \x03(\x0b\x32\x1a.kaskada.api.v1alpha.TableR\x06tables\x12/\n\x05views\x18\x02 \x03(\x0b\x32\x19.kaskada.api.v1alpha.ViewR\x05views\x12P\n\x10materializations\x18\x03 \x03(\x0b\x32$.kaskada.api.v1alpha.MaterializationR\x10materializationsB\xd9\x01\n\x17\x63om.kaskada.api.v1alphaB\tSpecProtoP\x01ZEgitlab.com/kaskada/kaskada/wren/gen/go/kaskada/api/v1alpha;apiv1alpha\xa2\x02\x03KAX\xaa\x02\x13Kaskada.Api.V1alpha\xca\x02\x13Kaskada\\Api\\V1alpha\xe2\x02\x1fKaskada\\Api\\V1alpha\\GPBMetadata\xea\x02\x15Kaskada::Api::V1alphab\x06proto3')



_SPEC = DESCRIPTOR.message_types_by_name['Spec']
Spec = _reflection.GeneratedProtocolMessageType('Spec', (_message.Message,), {
  'DESCRIPTOR' : _SPEC,
  '__module__' : 'kaskada.api.v1alpha.spec_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.Spec)
  })
_sym_db.RegisterMessage(Spec)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.kaskada.api.v1alphaB\tSpecProtoP\001ZEgitlab.com/kaskada/kaskada/wren/gen/go/kaskada/api/v1alpha;apiv1alpha\242\002\003KAX\252\002\023Kaskada.Api.V1alpha\312\002\023Kaskada\\Api\\V1alpha\342\002\037Kaskada\\Api\\V1alpha\\GPBMetadata\352\002\025Kaskada::Api::V1alpha'
  _SPEC._serialized_start=164
  _SPEC._serialized_end=353
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kaskada/api/v1alpha/staged_file.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from kaskada.fenl.v1alpha import schema_pb2 as kaskada_dot_fenl_dot_v1alpha_dot_schema__pb2
from kaskada.api.v1alpha import shared_pb2 as kaskada_dot_api_dot_v1alpha_dot_shared__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%kaskada/api/v1alpha/staged_file.proto\x12\x13kaskada.api.v1alpha\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a!kaskada/fenl/v1alpha/schema.proto\x1a kaskada/api/v1alpha/shared.proto\x1a\x17validate/validate.proto\"\xfa\x02\n\nStagedFile\x12\x1c\n\x07\x66ile_id\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x06\x66ileId\x12$\n\tfile_name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x08\x66ileName\x12@\n\x0b\x63reate_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\x12S\n\x15upload_completed_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\x13uploadCompletedTime\x12*\n\ncontent_id\x18\x05 \x01(\tB\x0b\xfa\x42\x08r\x06\x98\x01 \xd0\x01\x01R\tcontentId\x12*\n\x0e\x63ontent_length\x18\x06 \x01(\x03\x42\x03\xe0\x41\x03R\rcontentLength\x12\x39\n\x06schema\x18\x07 \x01(\x0b\x32\x1c.kaskada.fenl.v1alpha.SchemaB\x03\xe0\x41\x03R\x06schema\"x\n\x16ListStagedFilesRequest\x12\x16\n\x06search\x18\x01 \x01(\tR\x06search\x12\'\n\tpage_size\x18\x02 \x01(\x05\x42\n\xfa\x42\x07\x1a\x05\x18\xe8\x07(\x00R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"\xc6\x01\n\x17ListStagedFilesResponse\x12\x35\n\x05\x66iles\x18\x01 \x03(\x0b\x32\x1f.kaskada.api.v1alpha.StagedFileR\x05\x66iles\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12L\n\x0frequest_details\x18\x03 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetails\"8\n\x14GetStagedFileRequest\x12 \n\x07\x66ile_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x06\x66ileId\"\x9a\x01\n\x15GetStagedFileResponse\x12\x33\n\x04\x66ile\x18\x01 \x01(\x0b\x32\x1f.kaskada.api.v1alpha.StagedFileR\x04\x66ile\x12L\n\x0frequest_details\x18\x02 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetails\"X\n\x17\x43reateStagedFileRequest\x12=\n\x04\x66ile\x18\x01 \x01(\x0b\x32\x1f.kaskada.api.v1alpha.StagedFileB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x04\x66ile\"\xaf\x01\n\x18\x43reateStagedFileResponse\x12\x33\n\x04\x66ile\x18\x01 \x01(\x0b\x32\x1f.kaskada.api.v1alpha.StagedFileR\x04\x66ile\x12\x10\n\x03url\x18\x02 \x01(\tR\x03url\x12L\n\x0frequest_details\x18\x03 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetails2\xcc\x03\n\x11StagedFileService\x12\x8b\x01\n\x0fListStagedFiles\x12+.kaskada.api.v1alpha.ListStagedFilesRequest\x1a,.kaskada.api.v1alpha.ListStagedFilesResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/v1alpha/staged_files\x12\x91\x01\n\rGetStagedFile\x12).kaskada.api.v1alpha.GetStagedFileRequest\x1a*.kaskada.api.v1alpha.GetStagedFileResponse\")\x82\xd3\xe4\x93\x02#\x12!/v1alpha/staged_files/{file_id=*}\x12\x94\x01\n\x10\x43reateStagedFile\x12,.kaskada.api.v1alpha.CreateStagedFileRequest\x1a-.kaskada.api.v1alpha.CreateStagedFileResponse\"#\x82\xd3\xe4\x93\x02\x1d:\x04\x66ile\"\x15/v1alpha/staged_filesB\xdf\x01\n\x17\x63om.kaskada.api.v1alphaB\x0fStagedFileProtoP\x01ZEgitlab.com/kaskada/kaskada/wren/gen/go/kaskada/api/v1alpha;apiv1alpha\xa2\x02\x03KAX\xaa\x02\x13Kaskada.Api.V1alpha\xca\x02\x13Kaskada\\Api\\V1alpha\xe2\x02\x1fKaskada\\Api\\V1alpha\\GPBMetadata\xea\x02\x15Kaskada::Api::V1alphab\x06proto3')



_STAGEDFILE = DESCRIPTOR.message_types_by_name['StagedFile']
_LISTSTAGEDFILESREQUEST = DESCRIPTOR.message_types_by_name['ListStagedFilesRequest']
_LISTSTAGEDFILESRESPONSE = DESCRIPTOR.message_types_by_name['ListStagedFilesResponse']
_GETSTAGEDFILEREQUEST = DESCRIPTOR.message_types_by_name['GetStagedFileRequest']
_GETSTAGEDFILERESPONSE = DESCRIPTOR.message_types_by_name['GetStagedFileResponse']
_CREATESTAGEDFILEREQUEST = DESCRIPTOR.message_types_by_name['CreateStagedFileRequest']
_CREATESTAGEDFILERESPONSE = DESCRIPTOR.message_types_by_name['CreateStagedFileResponse']
StagedFile = _reflection.GeneratedProtocolMessageType('StagedFile', (_message.Message,), {
  'DESCRIPTOR' : _STAGEDFILE,
  '__module__' : 'kaskada.api.v1alpha.staged_file_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.StagedFile)
  })
_sym_db.RegisterMessage(StagedFile)

ListStagedFilesRequest = _reflection.GeneratedProtocolMessageType('ListStagedFilesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTSTAGEDFILESREQUEST,
  '__module__' : 'kaskada.api.v1alpha.staged_file_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.ListStagedFilesRequest)
  })
_sym_db.RegisterMessage(ListStagedFilesRequest)

ListStagedFilesResponse = _reflection.GeneratedProtocolMessageType('ListStagedFilesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSTAGEDFILESRESPONSE,
  '__module__' : 'kaskada.api.v1alpha.staged_file_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.ListStagedFilesResponse)
  })
_sym_db.RegisterMessage(ListStagedFilesResponse)

GetStagedFileRequest = _reflection.GeneratedProtocolMessageType('GetStagedFileRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSTAGEDFILEREQUEST,
  '__module__' : 'kaskada.api.v1alpha.staged_file_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.GetStagedFileRequest)
  })
_sym_db.RegisterMessage(GetStagedFileRequest)

GetStagedFileResponse = _reflection.GeneratedProtocolMessageType('GetStagedFileResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSTAGEDFILERESPONSE,
  '__module__' : 'kaskada.api.v1alpha.staged_file_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.GetStagedFileResponse)
  })
_sym_db.RegisterMessage(GetStagedFileResponse)

CreateStagedFileRequest = _reflection.GeneratedProtocolMessageType('CreateStagedFileRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATESTAGEDFILEREQUEST,
  '__module__' : 'kaskada.api.v1alpha.staged_file_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.CreateStagedFileRequest)
  })
_sym_db.RegisterMessage(CreateStagedFileRequest)

CreateStagedFileResponse = _reflection.GeneratedProtocolMessageType('CreateStagedFileResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATESTAGEDFILERESPONSE,
  '__module__' : 'kaskada.api.v1alpha.staged_file_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.CreateStagedFileResponse)
  })
_sym_db.RegisterMessage(CreateStagedFileResponse)

_STAGEDFILESERVICE = DESCRIPTOR.services_by_name['StagedFileService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.kaskada.api.v1alphaB\017StagedFileProtoP\001ZEgitlab.com/kaskada/kaskada/wren/gen/go/kaskada/api/v1alpha;apiv1alpha\242\002\003KAX\252\002\023Kaskada.Api.V1alpha\312\002\023Kaskada\\Api\\V1alpha\342\002\037Kaskada\\Api\\V1alpha\\GPBMetadata\352\002\025Kaskada::Api::V1alpha'
  _STAGEDFILE.fields_by_name['file_id']._options = None
  _STAGEDFILE.fields_by_name['file_id']._serialized_options = b'\340A\003'
  _STAGEDFILE.fields_by_name['file_name']._options = None
  _STAGEDFILE.fields_by_name['file_name']._serialized_options = b'\372B\004r\002\020\001'
  _STAGEDFILE.fields_by_name['create_time']._options = None
  _STAGEDFILE.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _STAGEDFILE.fields_by_name['upload_completed_time']._options = None
  _STAGEDFILE.fields_by_name['upload_completed_time']._serialized_options = b'\340A\003'
  _STAGEDFILE.fields_by_name['content_id']._options = None
  _STAGEDFILE.fields_by_name['content_id']._serialized_options = b'\372B\010r\006\230\001 \320\001\001'
  _STAGEDFILE.fields_by_name['content_length']._options = None
  _STAGEDFILE.fields_by_name['content_length']._serialized_options = b'\340A\003'
  _STAGEDFILE.fields_by_name['schema']._options = None
  _STAGEDFILE.fields_by_name['schema']._serialized_options = b'\340A\003'
  _LISTSTAGEDFILESREQUEST.fields_by_name['page_size']._options = None
  _LISTSTAGEDFILESREQUEST.fields_by_name['page_size']._serialized_options = b'\372B\007\032\005\030\350\007(\000'
  _GETSTAGEDFILEREQUEST.fields_by_name['file_id']._options = None
  _GETSTAGEDFILEREQUEST.fields_by_name['file_id']._serialized_options = b'\372B\004r\002\020\001'
  _CREATESTAGEDFILEREQUEST.fields_by_name['file']._options = None
  _CREATESTAGEDFILEREQUEST.fields_by_name['file']._serialized_options = b'\372B\005\212\001\002\020\001'
  _STAGEDFILESERVICE.methods_by_name['ListStagedFiles']._options = None
  _STAGEDFILESERVICE.methods_by_name['ListStagedFiles']._serialized_options = b'\202\323\344\223\002\027\022\025/v1alpha/staged_files'
  _STAGEDFILESERVICE.methods_by_name['GetStagedFile']._options = None
  _STAGEDFILESERVICE.methods_by_name['GetStagedFile']._serialized_options = b'\202\323\344\223\002#\022!/v1alpha/staged_files/{file_id=*}'
  _STAGEDFILESERVICE.methods_by_name['CreateStagedFile']._options = None
  _STAGEDFILESERVICE.methods_by_name['CreateStagedFile']._serialized_options = b'\202\323\344\223\002\035:\004file\"\025/v1alpha/staged_files'
  _STAGEDFILE._serialized_start=253
  _STAGEDFILE._serialized_end=631
  _LISTSTAGEDFILESREQUEST._serialized_start=633
  _LISTSTAGEDFILESREQUEST._serialized_end=753
  _LISTSTAGEDFILESRESPONSE._serialized_start=756
  _LISTSTAGEDFILESRESPONSE._serialized_end=954
  _GETSTAGEDFILEREQUEST._serialized_start=956
  _GETSTAGEDFILEREQUEST._serialized_end=1012
  _GETSTAGEDFILERESPONSE._serialized_start=1015
  _GETSTAGEDFILERESPONSE._serialized_end=1169
  _CREATESTAGEDFILEREQUEST._serialized_start=1171
  _CREATESTAGEDFILEREQUEST._serialized_end=1259
  _CREATESTAGEDFILERESPONSE._serialized_start=1262
  _CREATESTAGEDFILERESPONSE._serialized_end=1437
  _STAGEDFILESERVICE._serialized_start=1440
  _STAGEDFILESERVICE._serialized_end=1900
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kaskada/fenl/v1alpha/schema.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!kaskada/fenl/v1alpha/schema.proto\x12\x14kaskada.fenl.v1alpha\x1a\x1bgoogle/protobuf/empty.proto\"\xdd\x07\n\x08\x44\x61taType\x12L\n\tprimitive\x18\x01 \x01(\x0e\x32,.kaskada.fenl.v1alpha.DataType.PrimitiveTypeH\x00R\tprimitive\x12\x36\n\x06struct\x18\x02 \x01(\x0b\x32\x1c.kaskada.fenl.v1alpha.SchemaH\x00R\x06struct\x12\x30\n\x06window\x18\x03 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00R\x06window\"\x90\x06\n\rPrimitiveType\x12\x1e\n\x1aPRIMITIVE_TYPE_UNSPECIFIED\x10\x00\x12\x17\n\x13PRIMITIVE_TYPE_NULL\x10\x01\x12\x17\n\x13PRIMITIVE_TYPE_BOOL\x10\x02\x12\x15\n\x11PRIMITIVE_TYPE_I8\x10\x03\x12\x16\n\x12PRIMITIVE_TYPE_I16\x10\x04\x12\x16\n\x12PRIMITIVE_TYPE_I32\x10\x05\x12\x16\n\x12PRIMITIVE_TYPE_I64\x10\x06\x12\x15\n\x11PRIMITIVE_TYPE_U8\x10\x07\x12\x16\n\x12PRIMITIVE_TYPE_U16\x10\x08\x12\x16\n\x12PRIMITIVE_TYPE_U32\x10\t\x12\x16\n\x12PRIMITIVE_TYPE_U64\x10\n\x12\x16\n\x12PRIMITIVE_TYPE_F16\x10\x0b\x12\x16\n\x12PRIMITIVE_TYPE_F32\x10\x0c\x12\x16\n\x12PRIMITIVE_TYPE_F64\x10\r\x12\x19\n\x15PRIMITIVE_TYPE_STRING\x10\x0e\x12$\n PRIMITIVE_TYPE_INTERVAL_DAY_TIME\x10\x0f\x12&\n\"PRIMITIVE_TYPE_INTERVAL_YEAR_MONTH\x10\x10\x12\"\n\x1ePRIMITIVE_TYPE_DURATION_SECOND\x10\x11\x12\'\n#PRIMITIVE_TYPE_DURATION_MILLISECOND\x10\x12\x12\'\n#PRIMITIVE_TYPE_DURATION_MICROSECOND\x10\x13\x12&\n\"PRIMITIVE_TYPE_DURATION_NANOSECOND\x10\x14\x12#\n\x1fPRIMITIVE_TYPE_TIMESTAMP_SECOND\x10\x15\x12(\n$PRIMITIVE_TYPE_TIMESTAMP_MILLISECOND\x10\x16\x12(\n$PRIMITIVE_TYPE_TIMESTAMP_MICROSECOND\x10\x17\x12\'\n#PRIMITIVE_TYPE_TIMESTAMP_NANOSECOND\x10\x18\x42\x06\n\x04kind\"\x9e\x01\n\x06Schema\x12:\n\x06\x66ields\x18\x01 \x03(\x0b\x32\".kaskada.fenl.v1alpha.Schema.FieldR\x06\x66ields\x1aX\n\x05\x46ield\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12;\n\tdata_type\x18\x02 \x01(\x0b\x32\x1e.kaskada.fenl.v1alpha.DataTypeR\x08\x64\x61taTypeB\xe2\x01\n\x18\x63om.kaskada.fenl.v1alphaB\x0bSchemaProtoP\x01ZGgitlab.com/kaskada/kaskada/wren/gen/go/kaskada/fenl/v1alpha;fenlv1alpha\xa2\x02\x03KFX\xaa\x02\x14Kaskada.Fenl.V1alpha\xca\x02\x14Kaskada\\Fenl\\V1alpha\xe2\x02 Kaskada\\Fenl\\V1alpha\\GPBMetadata\xea\x02\x16Kaskada::Fenl::V1alphab\x06proto3')



_DATATYPE = DESCRIPTOR.message_types_by_name['DataType']
_SCHEMA = DESCRIPTOR.message_types_by_name['Schema']
_SCHEMA_FIELD = _SCHEMA.nested_types_by_name['Field']
_DATATYPE_PRIMITIVETYPE = _DATATYPE.enum_types_by_name['PrimitiveType']
DataType = _reflection.GeneratedProtocolMessageType('DataType', (_message.Message,), {
  'DESCRIPTOR' : _DATATYPE,
  '__module__' : 'kaskada.fenl.v1alpha.schema_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.fenl.v1alpha.DataType)
  })
_sym_db.RegisterMessage(DataType)

Schema = _reflection.GeneratedProtocolMessageType('Schema', (_message.Message,), {

  'Field' : _reflection.GeneratedProtocolMessageType('Field', (_message.Message,), {
    'DESCRIPTOR' : _SCHEMA_FIELD,
    '__module__' : 'kaskada.fenl.v1alpha.schema_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.fenl.v1alpha.Schema.Field)
    })
  ,
  'DESCRIPTOR' : _SCHEMA,
  '__module__' : 'kaskada.fenl.v1alpha.schema_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.fenl.v1alpha.Schema)
  })
_sym_db.RegisterMessage(Schema)
_sym_db.RegisterMessage(Schema.Field)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030com.kaskada.fenl.v1alphaB\013SchemaProtoP\001ZGgitlab.com/kaskada/kaskada/wren/gen/go/kaskada/fenl/v1alpha;fenlv1alpha\242\002\003KFX\252\002\024Kaskada.Fenl.V1alpha\312\002\024Kaskada\\Fenl\\V1alpha\342\002 Kaskada\\Fenl\\V1alpha\\GPBMetadata\352\002\026Kaskada::Fenl::V1alpha'
  _DATATYPE._serialized_start=89
  _DATATYPE._serialized_end=1078
  _DATATYPE_PRIMITIVETYPE._serialized_start=286
  _DATATYPE_PRIMITIVETYPE._serialized_end=1070
  _SCHEMA._serialized_start=1081
  _SCHEMA._serialized_end=1239
  _SCHEMA_FIELD._serialized_start=1151
  _SCHEMA_FIELD._serialized_end=1239
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kaskada/api/v1alpha/table.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from kaskada.api.v1alpha import shared_pb2 as kaskada_dot_api_dot_v1alpha_dot_shared__pb2
from kaskada.fenl.v1alpha import schema_pb2 as kaskada_dot_fenl_dot_v1alpha_dot_schema__pb2
from kaskada.shared.v1alpha import catalog_pb2 as kaskada_dot_shared_dot_v1alpha_dot_catalog__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fkaskada/api/v1alpha/table.proto\x12\x13kaskada.api.v1alpha\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a kaskada/api/v1alpha/shared.proto\x1a!kaskada/fenl/v1alpha/schema.proto\x1a$kaskada/shared/v1alpha/catalog.proto\x1a\x17validate/validate.proto\"\xc1\x07\n\x05Table\x12\x1e\n\x08table_id\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x07tableId\x12&\n\ntable_name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\ttableName\x12\x31\n\x10time_column_name\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x0etimeColumnName\x12<\n\x16\x65ntity_key_column_name\x18\x04 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x13\x65ntityKeyColumnName\x12\x35\n\x17old_subsort_column_name\x18\x05 \x01(\tR\x14oldSubsortColumnName\x12\x1f\n\x0bgrouping_id\x18\x07 \x01(\tR\ngroupingId\x12@\n\x0b\x63reate_time\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\x12@\n\x0bupdate_time\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\nupdateTime\x12\x1d\n\x07version\x18\n \x01(\x03\x42\x03\xe0\x41\x03R\x07version\x12\x39\n\x06schema\x18\r \x01(\x0b\x32\x1c.kaskada.fenl.v1alpha.SchemaB\x03\xe0\x41\x03R\x06schema\x12\"\n\nfile_count\x18\x0e \x01(\x03\x42\x03\xe0\x41\x03R\tfileCount\x12U\n\x13subsort_column_name\x18\x0f \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x07\xfa\x42\x04r\x02\x10\x01R\x11subsortColumnName\x12\x44\n\x07kaskada\x18\x10 \x01(\x0b\x32(.kaskada.api.v1alpha.Table.KaskadaSourceH\x00R\x07kaskada\x12\x44\n\x07iceberg\x18\x11 \x01(\x0b\x32(.kaskada.api.v1alpha.Table.IcebergSourceH\x00R\x07iceberg\x1a\x0f\n\rKaskadaSource\x1a\x94\x01\n\rIcebergSource\x12=\n\x06\x63onfig\x18\x01 \x01(\x0b\x32%.kaskada.shared.v1alpha.CatalogConfigR\x06\x63onfig\x12%\n\tnamespace\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\tnamespace\x12\x1d\n\ntable_name\x18\x03 \x01(\tR\ttableNameB\x08\n\x06sourceJ\x04\x08\x06\x10\x07J\x04\x08\x0b\x10\x0cJ\x04\x08\x0c\x10\r\"\x94\x02\n\x13TableVersionDetails\x12\x18\n\x07version\x18\x01 \x01(\x03R\x07version\x12@\n\x0b\x63reate_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\x12\x1b\n\x06schema\x18\x03 \x01(\tB\x03\xe0\x41\x03R\x06schema\x12P\n\nfile_infos\x18\x05 \x03(\x0b\x32\x31.kaskada.api.v1alpha.TableVersionDetails.FileInfoR\tfileInfos\x1a,\n\x08\x46ileInfo\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x10\n\x03key\x18\x02 \x01(\tR\x03keyJ\x04\x08\x04\x10\x05\"s\n\x11ListTablesRequest\x12\x16\n\x06search\x18\x01 \x01(\tR\x06search\x12\'\n\tpage_size\x18\x02 \x01(\x05\x42\n\xfa\x42\x07\x1a\x05\x18\xe8\x07(\x00R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"\xbe\x01\n\x12ListTablesResponse\x12\x32\n\x06tables\x18\x01 \x03(\x0b\x32\x1a.kaskada.api.v1alpha.TableR\x06tables\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12L\n\x0frequest_details\x18\x03 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetails\"9\n\x0fGetTableRequest\x12&\n\ntable_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\ttableName\"\x92\x01\n\x10GetTableResponse\x12\x30\n\x05table\x18\x01 \x01(\x0b\x32\x1a.kaskada.api.v1alpha.TableR\x05table\x12L\n\x0frequest_details\x18\x02 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetails\"P\n\x12\x43reateTableRequest\x12:\n\x05table\x18\x01 \x01(\x0b\x32\x1a.kaskada.api.v1alpha.TableB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x05table\"\x95\x01\n\x13\x43reateTableResponse\x12\x30\n\x05table\x18\x01 \x01(\x0b\x32\x1a.kaskada.api.v1alpha.TableR\x05table\x12L\n\x0frequest_details\x18\x02 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetails\"R\n\x12\x44\x65leteTableRequest\x12&\n\ntable_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\ttableName\x12\x14\n\x05\x66orce\x18\x02 \x01(\x08R\x05\x66orce\"\x87\x01\n\x13\x44\x65leteTableResponse\x12\"\n\rdata_token_id\x18\x01 \x01(\tR\x0b\x64\x61taTokenId\x12L\n\x0frequest_details\x18\x02 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetails\"\xb8\x02\n\x0fLoadDataRequest\x12&\n\ntable_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\ttableName\x12\"\n\x07\x66ile_id\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00R\x06\x66ileId\x12O\n\x10\x65xternal_s3_file\x18\x03 \x01(\x0b\x32#.kaskada.api.v1alpha.ExternalS3FileH\x00R\x0e\x65xternalS3File\x12\x61\n\x10refresh_external\x18\x04 \x01(\x0b\x32\x34.kaskada.api.v1alpha.LoadDataRequest.RefreshExternalH\x00R\x0frefreshExternal\x1a\x11\n\x0fRefreshExternalB\x12\n\x0bsource_data\x12\x03\xf8\x42\x01\"\x84\x01\n\x10LoadDataResponse\x12\"\n\rdata_token_id\x18\x01 \x01(\tR\x0b\x64\x61taTokenId\x12L\n\x0frequest_details\x18\x02 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetails2\x94\x05\n\x0cTableService\x12v\n\nListTables\x12&.kaskada.api.v1alpha.ListTablesRequest\x1a\'.kaskada.api.v1alpha.ListTablesResponse\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/v1alpha/tables\x12\x7f\n\x08GetTable\x12$.kaskada.api.v1alpha.GetTableRequest\x1a%.kaskada.api.v1alpha.GetTableResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/v1alpha/tables/{table_name=*}\x12\x80\x01\n\x0b\x43reateTable\x12\'.kaskada.api.v1alpha.CreateTableRequest\x1a(.kaskada.api.v1alpha.CreateTableResponse\"\x1e\x82\xd3\xe4\x93\x02\x18:\x05table\"\x0f/v1alpha/tables\x12\x88\x01\n\x0b\x44\x65leteTable\x12\'.kaskada.api.v1alpha.DeleteTableRequest\x1a(.kaskada.api.v1alpha.DeleteTableResponse\"&\x82\xd3\xe4\x93\x02 *\x1e/v1alpha/tables/{table_name=*}\x12}\n\x08LoadData\x12$.kaskada.api.v1alpha.LoadDataRequest\x1a%.kaskada.api.v1alpha.LoadDataResponse\"$\x82\xd3\xe4\x93\x02\x1e:\x01*\"\x19/v1alpha/tables/load_dataB\xda\x01\n\x17\x63om.kaskada.api.v1alphaB\nTableProtoP\x01ZEgitlab.com/kaskada/kaskada/wren/gen/go/kaskada/api/v1alpha;apiv1alpha\xa2\x02\x03KAX\xaa\x02\x13Kaskada.Api.V1alpha\xca\x02\x13Kaskada\\Api\\V1alpha\xe2\x02\x1fKaskada\\Api\\V1alpha\\GPBMetadata\xea\x02\x15Kaskada::Api::V1alphab\x06proto3')



_TABLE = DESCRIPTOR.message_types_by_name['Table']
_TABLE_KASKADASOURCE = _TABLE.nested_types_by_name['KaskadaSource']
_TABLE_ICEBERGSOURCE = _TABLE.nested_types_by_name['IcebergSource']
_TABLEVERSIONDETAILS = DESCRIPTOR.message_types_by_name['TableVersionDetails']
_TABLEVERSIONDETAILS_FILEINFO = _TABLEVERSIONDETAILS.nested_types_by_name['FileInfo']
_LISTTABLESREQUEST = DESCRIPTOR.message_types_by_name['ListTablesRequest']
_LISTTABLESRESPONSE = DESCRIPTOR.message_types_by_name['ListTablesResponse']
_GETTABLEREQUEST = DESCRIPTOR.message_types_by_name['GetTableRequest']
_GETTABLERESPONSE = DESCRIPTOR.message_types_by_name['GetTableResponse']
_CREATETABLEREQUEST = DESCRIPTOR.message_types_by_name['CreateTableRequest']
_CREATETABLERESPONSE = DESCRIPTOR.message_types_by_name['CreateTableResponse']
_DELETETABLEREQUEST = DESCRIPTOR.message_types_by_name['DeleteTableRequest']
_DELETETABLERESPONSE = DESCRIPTOR.message_types_by_name['DeleteTableResponse']
_LOADDATAREQUEST = DESCRIPTOR.message_types_by_name['LoadDataRequest']
_LOADDATAREQUEST_REFRESHEXTERNAL = _LOADDATAREQUEST.nested_types_by_name['RefreshExternal']
_LOADDATARESPONSE = DESCRIPTOR.message_types_by_name['LoadDataResponse']
Table = _reflection.GeneratedProtocolMessageType('Table', (_message.Message,), {

  'KaskadaSource' : _reflection.GeneratedProtocolMessageType('KaskadaSource', (_message.Message,), {
    'DESCRIPTOR' : _TABLE_KASKADASOURCE,
    '__module__' : 'kaskada.api.v1alpha.table_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.Table.KaskadaSource)
    })
  ,

  'IcebergSource' : _reflection.GeneratedProtocolMessageType('IcebergSource', (_message.Message,), {
    'DESCRIPTOR' : _TABLE_ICEBERGSOURCE,
    '__module__' : 'kaskada.api.v1alpha.table_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.Table.IcebergSource)
    })
  ,
  'DESCRIPTOR' : _TABLE,
  '__module__' : 'kaskada.api.v1alpha.table_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.Table)
  })
_sym_db.RegisterMessage(Table)
_sym_db.RegisterMessage(Table.KaskadaSource)
_sym_db.RegisterMessage(Table.IcebergSource)

TableVersionDetails = _reflection.GeneratedProtocolMessageType('TableVersionDetails', (_message.Message,), {

  'FileInfo' : _reflection.GeneratedProtocolMessageType('FileInfo', (_message.Message,), {
    'DESCRIPTOR' : _TABLEVERSIONDETAILS_FILEINFO,
    '__module__' : 'kaskada.api.v1alpha.table_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.TableVersionDetails.FileInfo)
    })
  ,
  'DESCRIPTOR' : _TABLEVERSIONDETAILS,
  '__module__' : 'kaskada.api.v1alpha.table_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.TableVersionDetails)
  })
_sym_db.RegisterMessage(TableVersionDetails)
_sym_db.RegisterMessage(TableVersionDetails.FileInfo)

ListTablesRequest = _reflection.GeneratedProtocolMessageType('ListTablesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTTABLESREQUEST,
  '__module__' : 'kaskada.api.v1alpha.table_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.ListTablesRequest)
  })
_sym_db.RegisterMessage(ListTablesRequest)

ListTablesResponse = _reflection.GeneratedProtocolMessageType('ListTablesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTTABLESRESPONSE,
  '__module__' : 'kaskada.api.v1alpha.table_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.ListTablesResponse)
  })
_sym_db.RegisterMessage(ListTablesResponse)

GetTableRequest = _reflection.GeneratedProtocolMessageType('GetTableRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTABLEREQUEST,
  '__module__' : 'kaskada.api.v1alpha.table_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.GetTableRequest)
  })
_sym_db.RegisterMessage(GetTableRequest)

GetTableResponse = _reflection.GeneratedProtocolMessageType('GetTableResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETTABLERESPONSE,
  '__module__' : 'kaskada.api.v1alpha.table_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.GetTableResponse)
  })
_sym_db.RegisterMessage(GetTableResponse)

CreateTableRequest = _reflection.GeneratedProtocolMessageType('CreateTableRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATETABLEREQUEST,
  '__module__' : 'kaskada.api.v1alpha.table_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.CreateTableRequest)
  })
_sym_db.RegisterMessage(CreateTableRequest)

CreateTableResponse = _reflection.GeneratedProtocolMessageType('CreateTableResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATETABLERESPONSE,
  '__module__' : 'kaskada.api.v1alpha.table_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.CreateTableResponse)
  })
_sym_db.RegisterMessage(CreateTableResponse)

DeleteTableRequest = _reflection.GeneratedProtocolMessageType('DeleteTableRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETETABLEREQUEST,
  '__module__' : 'kaskada.api.v1alpha.table_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.DeleteTableRequest)
  })
_sym_db.RegisterMessage(DeleteTableRequest)

DeleteTableResponse = _reflection.GeneratedProtocolMessageType('DeleteTableResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETETABLERESPONSE,
  '__module__' : 'kaskada.api.v1alpha.table_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.DeleteTableResponse)
  })
_sym_db.RegisterMessage(DeleteTableResponse)

LoadDataRequest = _reflection.GeneratedProtocolMessageType('LoadDataRequest', (_message.Message,), {

  'RefreshExternal' : _reflection.GeneratedProtocolMessageType('RefreshExternal', (_message.Message,), {
    'DESCRIPTOR' : _LOADDATAREQUEST_REFRESHEXTERNAL,
    '__module__' : 'kaskada.api.v1alpha.table_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.LoadDataRequest.RefreshExternal)
    })
  ,
  'DESCRIPTOR' : _LOADDATAREQUEST,
  '__module__' : 'kaskada.api.v1alpha.table_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.LoadDataRequest)
  })
_sym_db.RegisterMessage(LoadDataRequest)
_sym_db.RegisterMessage(LoadDataRequest.RefreshExternal)

LoadDataResponse = _reflection.GeneratedProtocolMessageType('LoadDataResponse', (_message.Message,), {
  'DESCRIPTOR' : _LOADDATARESPONSE,
  '__module__' : 'kaskada.api.v1alpha.table_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.LoadDataResponse)
  })
_sym_db.RegisterMessage(LoadDataResponse)

_TABLESERVICE = DESCRIPTOR.services_by_name['TableService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.kaskada.api.v1alphaB\nTableProtoP\001ZEgitlab.com/kaskada/kaskada/wren/gen/go/kaskada/api/v1alpha;apiv1alpha\242\002\003KAX\252\002\023Kaskada.Api.V1alpha\312\002\023Kaskada\\Api\\V1alpha\342\002\037Kaskada\\Api\\V1alpha\\GPBMetadata\352\002\025Kaskada::Api::V1alpha'
  _TABLE_ICEBERGSOURCE.fields_by_name['namespace']._options = None
  _TABLE_ICEBERGSOURCE.fields_by_name['namespace']._serialized_options = b'\372B\004r\002\020\001'
  _TABLE.fields_by_name['table_id']._options = None
  _TABLE.fields_by_name['table_id']._serialized_options = b'\340A\003'
  _TABLE.fields_by_name['table_name']._options = None
  _TABLE.fields_by_name['table_name']._serialized_options = b'\372B\004r\002\020\001'
  _TABLE.fields_by_name['time_column_name']._options = None
  _TABLE.fields_by_name['time_column_name']._serialized_options = b'\372B\004r\002\020\001'
  _TABLE.fields_by_name['entity_key_column_name']._options = None
  _TABLE.fields_by_name['entity_key_column_name']._serialized_options = b'\372B\004r\002\020\001'
  _TABLE.fields_by_name['create_time']._options = None
  _TABLE.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _TABLE.fields_by_name['update_time']._options = None
  _TABLE.fields_by_name['update_time']._serialized_options = b'\340A\003'
  _TABLE.fields_by_name['version']._options = None
  _TABLE.fields_by_name['version']._serialized_options = b'\340A\003'
  _TABLE.fields_by_name['schema']._options = None
  _TABLE.fields_by_name['schema']._serialized_options = b'\340A\003'
  _TABLE.fields_by_name['file_count']._options = None
  _TABLE.fields_by_name['file_count']._serialized_options = b'\340A\003'
  _TABLE.fields_by_name['subsort_column_name']._options = None
  _TABLE.fields_by_name['subsort_column_name']._serialized_options = b'\372B\004r\002\020\001'
  _TABLEVERSIONDETAILS.fields_by_name['create_time']._options = None
  _TABLEVERSIONDETAILS.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _TABLEVERSIONDETAILS.fields_by_name['schema']._options = None
  _TABLEVERSIONDETAILS.fields_by_name['schema']._serialized_options = b'\340A\003'
  _LISTTABLESREQUEST.fields_by_name['page_size']._options = None
  _LISTTABLESREQUEST.fields_by_name['page_size']._serialized_options = b'\372B\007\032\005\030\350\007(\000'
  _GETTABLEREQUEST.fields_by_name['table_name']._options = None
  _GETTABLEREQUEST.fields_by_name['table_name']._serialized_options = b'\372B\004r\002\020\001'
  _CREATETABLEREQUEST.fields_by_name['table']._options = None
  _CREATETABLEREQUEST.fields_by_name['table']._serialized_options = b'\372B\005\212\001\002\020\001'
  _DELETETABLEREQUEST.fields_by_name['table_name']._options = None
  _DELETETABLEREQUEST.fields_by_name['table_name']._serialized_options = b'\372B\004r\002\020\001'
  _LOADDATAREQUEST.oneofs_by_name['source_data']._options = None
  _LOADDATAREQUEST.oneofs_by_name['source_data']._serialized_options = b'\370B\001'
  _LOADDATAREQUEST.fields_by_name['table_name']._options = None
  _LOADDATAREQUEST.fields_by_name['table_name']._serialized_options = b'\372B\004r\002\020\001'
  _LOADDATAREQUEST.fields_by_name['file_id']._options = None
  _LOADDATAREQUEST.fields_by_name['file_id']._serialized_options = b'\372B\004r\002\020\001'
  _TABLESERVICE.methods_by_name['ListTables']._options = None
  _TABLESERVICE.methods_by_name['ListTables']._serialized_options = b'\202\323\344\223\002\021\022\017/v1alpha/tables'
  _TABLESERVICE.methods_by_name['GetTable']._options = None
  _TABLESERVICE.methods_by_name['GetTable']._serialized_options = b'\202\323\344\223\002 \022\036/v1alpha/tables/{table_name=*}'
  _TABLESERVICE.methods_by_name['CreateTable']._options = None
  _TABLESERVICE.methods_by_name['CreateTable']._serialized_options = b'\202\323\344\223\002\030:\005table\"\017/v1alpha/tables'
  _TABLESERVICE.methods_by_name['DeleteTable']._options = None
  _TABLESERVICE.methods_by_name['DeleteTable']._serialized_options = b'\202\323\344\223\002 *\036/v1alpha/tables/{table_name=*}'
  _TABLESERVICE.methods_by_name['LoadData']._options = None
  _TABLESERVICE.methods_by_name['LoadData']._serialized_options = b'\202\323\344\223\002\036:\001*\"\031/v1alpha/tables/load_data'
  _TABLE._serialized_start=346
  _TABLE._serialized_end=1307
  _TABLE_KASKADASOURCE._serialized_start=1113
  _TABLE_KASKADASOURCE._serialized_end=1128
  _TABLE_ICEBERGSOURCE._serialized_start=1131
  _TABLE_ICEBERGSOURCE._serialized_end=1279
  _TABLEVERSIONDETAILS._serialized_start=1310
  _TABLEVERSIONDETAILS._serialized_end=1586
  _TABLEVERSIONDETAILS_FILEINFO._serialized_start=1536
  _TABLEVERSIONDETAILS_FILEINFO._serialized_end=1580
  _LISTTABLESREQUEST._serialized_start=1588
  _LISTTABLESREQUEST._serialized_end=1703
  _LISTTABLESRESPONSE._serialized_start=1706
  _LISTTABLESRESPONSE._serialized_end=1896
  _GETTABLEREQUEST._serialized_start=1898
  _GETTABLEREQUEST._serialized_end=1955
  _GETTABLERESPONSE._serialized_start=1958
  _GETTABLERESPONSE._serialized_end=2104
  _CREATETABLEREQUEST._serialized_start=2106
  _CREATETABLEREQUEST._serialized_end=2186
  _CREATETABLERESPONSE._serialized_start=2189
  _CREATETABLERESPONSE._serialized_end=2338
  _DELETETABLEREQUEST._serialized_start=2340
  _DELETETABLEREQUEST._serialized_end=2422
  _DELETETABLERESPONSE._serialized_start=2425
  _DELETETABLERESPONSE._serialized_end=2560
  _LOADDATAREQUEST._serialized_start=2563
  _LOADDATAREQUEST._serialized_end=2875
  _LOADDATAREQUEST_REFRESHEXTERNAL._serialized_start=2838
  _LOADDATAREQUEST_REFRESHEXTERNAL._serialized_end=2855
  _LOADDATARESPONSE._serialized_start=2878
  _LOADDATARESPONSE._serialized_end=3010
  _TABLESERVICE._serialized_start=3013
  _TABLESERVICE._serialized_end=3673
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from kaskada.api.v1alpha import credential_pb2 as kaskada_dot_api_dot_v1alpha_dot_credential__pb2


class CredentialServiceStub(object):
    """A service for managing Kaskada API credentials.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Get = channel.unary_unary(
                '/kaskada.api.v1alpha.CredentialService/Get',
                request_serializer=kaskada_dot_api_dot_v1alpha_dot_credential__pb2.GetCredentialRequest.SerializeToString,
                response_deserializer=kaskada_dot_api_dot_v1alpha_dot_credential__pb2.GetCredentialResponse.FromString,
                )


class CredentialServiceServicer(object):
    """A service for managing Kaskada API credentials.
    """

    def Get(self, request, context):
        """Gets API credentials.

        Credentials can be used to access the Kaskada API using a client
        library or directly using the REST endpoint.

        The returned credentials may be used by providing them to any of the
        Kaskada-maintained client libraries when asked for client-id and
        client-secret.

        The client-id and client-secret may be used independent of a client
        library. To do so you must generate a short-lived JWT bearer token by
        making a POST request as follows:

        curl --request POST \
        --url https://kaskada.us.auth0.com/oauth/token \
        --header 'content-type: application/json' \
        --data
        '{"client_id":"<client-id>","client_secret":"<client-secret>","audience":"https://api.prod.kaskada.com","grant_type":"client_credentials"}'

        If successful, the response body will include a JWT access token:

        {
        "access_token": "<token>",
        "token_type": "Bearer"
        }

        The token grants access to the Kaskada API to any gRPC or HTTP
        request that provides the token in the "Authorization" header /
        metadata:

        curl --request GET \
        --url http://api.kaskada.com/v1alpha/tables/ \
        --header 'authorization: Bearer <token>'

        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_CredentialServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=kaskada_dot_api_dot_v1alpha_dot_credential__pb2.GetCredentialRequest.FromString,
                    response_serializer=kaskada_dot_api_dot_v1alpha_dot_credential__pb2.GetCredentialResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'kaskada.api.v1alpha.CredentialService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class CredentialService(object):
    """A service for managing Kaskada API credentials.
    """

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/kaskada.api.v1alpha.CredentialService/Get',
            kaskada_dot_api_dot_v1alpha_dot_credential__pb2.GetCredentialRequest.SerializeToString,
            kaskada_dot_api_dot_v1alpha_dot_credential__pb2.GetCredentialResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
